{% load static %}

<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <meta name="theme-color" content="#000000" />
    <meta
      name="description"
      content="Web site created using react django app"
    />
    <title>React Django App</title>
  </head>
  <body>

    <div id="root"></div>
    <script src="{% static './main/main.js' %}"></script>

  </body>
</html>
